@@ -2,44 +2,52 @@ import copy
 from urllib import urlencode, urlopen
 from json import loads
 from xml.dom import minidom
+from datetime import datetime
+from traceback import format_exc
+import logging
+
+logger = logging.getLogger(__name__)
 
 class GeocodeService():
     """
     A tuple of classes representing the geocoders that will be used
     to find addresses for the given locations
     """
-    _preprocessors = []
-    """
-    Preprocessor classes to apply to the given PlaceQuery
-    """
-    _postprocessors = []
-    """
-    Postprocessor classes to apply to the list of Candidates obtained
-    """
-    _settings = {}
-    """
-    Settings for this geocoder
-    """
+
     _endpoint = ''
     """
     API endpoint URL to use
     """
 
-    def _init_helper(self, preprocessors, postprocessors, settings):
+    def __init__(self, preprocessors=None, postprocessors=None,
+            settings=None):
         """
         Overwrite _preprocessors, _postprocessors, and _settings
-        if they are set. The default for processors is None, because [] would
-        indicate that no pre- or post-processors should be used. Settings
-        overwrite default/existing _settings dictionary pairs if they are already set.
+        if they are set.
         """
+
+        self._preprocessors = []
+        """
+        Preprocessor classes to apply to the given PlaceQuery
+        """
+        self._postprocessors = []
+        """
+        Postprocessor classes to apply to the list of Candidates obtained
+        """
+        self._settings = {}
+        """
+        Settings for this geocoder
+        """
+        # self._endpoint = ''
         if preprocessors is not None:
             self._preprocessors = preprocessors
         if postprocessors is not None:
             self._postprocessors = postprocessors
-        for key in settings:
-            self._settings[key] = settings[key]   
+        if settings is not None:
+            for key in settings:
+                self._settings[key] = settings[key]   
 
-    def _settings_checker(self, required_settings=[], accept_none=True):
+    def _settings_checker(self, required_settings=None, accept_none=True):
         """
         Take a list of required _settings dictionary keys
         and make sure they are set. This can be added to a custom
@@ -57,20 +65,14 @@ class GeocodeService():
          * bool ``True`` if all required settings exist, OR
          * str ``keyname`` for the first key that is not found in _settings.
         """
-        for keyname in required_settings:
-            if keyname not in self._settings:
-                return keyname
-            if accept_none is False and self._settings[keyname] is None:
-                return keyname
+        if required_settings is not None:
+            for keyname in required_settings:
+                if keyname not in self._settings:
+                    return keyname
+                if accept_none is False and self._settings[keyname] is None:
+                    return keyname
         return True
             
-
-    def __init__(self, preprocessors=None, postprocessors=None, settings={}):
-        """
-        Constructor for GeocodeService objects.
-        """
-        self._init_helper(preprocessors, postprocessors, settings)
-
     def _get_json_obj(self, endpoint, query):
         """
         Return False if connection could not be made.
@@ -79,14 +81,18 @@ class GeocodeService():
         try:
             response = urlopen('%s?%s' % (endpoint, urlencode(query)))
         except:
-            raise Exception('Could not connect') #TODO: log this error internally (could not connect, etc)
+            logger.error("%s couldn't connect to server" %
+                self.get_service_name())
+            logger.error(format_exc())
             return False
         if response.code != 200: return False
         content = response.read()  
         try:  
             return loads(content)
-        except ValueError as ex:
-            raise Exception('Could not decode JSON: %s' % ex) #TODO: log this error internally 
+        except ValueError:
+            logger.error("%s couldn't decode JSON: %s" % 
+                self.get_service_name, content)
+            logger.error(format_exc())
             return False
 
     def _get_xml_doc(self, endpoint, query):
@@ -97,7 +103,9 @@ class GeocodeService():
         try:
             response = urlopen('%s?%s' % (endpoint, urlencode(query)))
         except:
-            raise Exception('Could not connect') #TODO: log this error internally (could not connect, etc)
+            logger.error("%s couldn't connect to server" %
+                self.get_service_name())
+            logger.error(format_exc())
             return False
         if response.code != 200: return False
         return minidom.parse(response)
@@ -121,7 +129,17 @@ class GeocodeService():
             processed_pq = p.process(processed_pq)
             if processed_pq == False: return []
         
-        candidates = self._geocode(processed_pq)
+    
+        try:
+            start = datetime.now()
+            candidates = self._geocode(processed_pq)
+            end = datetime.now()
+            logger.info('GEOCODER: %s; results %d; time %s;' %
+                (self.__class__.__name__, len(candidates), end-start))
+        except:
+            logger.info('GEOCODER: %s; Exception when attempting to geocode %s' %
+                (self.__class__.__name__, format_exc()))
+            candidates = []
 
         for p in self._postprocessors: # apply universal candidate postprocessing
             candidates = p.process(candidates) # merge lists
@@ -129,4 +147,4 @@ class GeocodeService():
         return candidates
     
     def get_service_name(self):
-        return self.__name__
+        return self.__class__.__name__
